@@ -138,22 +138,10 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                # stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
-                # exit_status = stdout.channel.recv_exit_status()
-                # std_output = stdout.read().decode()
-                # std_err = stderr.read().decode()
-                ssh_tty = self.__ssh.invoke_shell()
-                command = f"nohup {cmd} > /dev/null 2>&1 &\n"
-                ssh_tty.send(command)
-                output=""
-                while True:
-                    if ssh_tty.recv_ready():
-                        output += ssh_tty.recv(1024).decode()
-                    else:
-                        break
-                std_output=output
-                exit_status=ssh_tty.recv_exit_status()
-                std_err=ssh_tty.recv_stderr()
+                stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
+                exit_status = stdout.channel.recv_exit_status()
+                std_output = stdout.read().decode()
+                std_err = stderr.read().decode()
                 log.info(
                     f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, output is:{std_output} and stderr:{std_err}.")
                 return ExecResult(exit_status, std_output, std_err)
